@@ -14,15 +14,6 @@ import logging
 import shutil
 from typing import Callable, Optional
 from urllib import request
-try:
-    import cv2 as cv
-except ImportError as e:
-    cv = None
-
-try:
-    import cv2 as cv
-except ImportError as e:
-    cv = None
 
 
 __all__ = ["PathManager", "get_cache_dir", "file_lock"]
@@ -609,6 +600,8 @@ class ImageSourceIter(SourceIter):
     def __init__(self, src, exit_auto=True):
         super(ImageSourceIter, self).__init__(src, exit_auto)
 
+        import cv2 as cv
+
         self._index_sources()
         self.is_written = False
         self.save_f = None
@@ -720,18 +713,6 @@ class ImageSourceIter(SourceIter):
                     # clean up remove saved file.
                     os.remove(self.save_f)
 
-    def waitKey(self):
-        if self.video_mode:
-            cv.waitKey(1)
-        else:
-            cv.waitKey(0)
-
-
-def next_item(iter):
-    itm = next(iter)
-    if isinstance(itm, str):
-        itm = cv.imread(itm)
-    return itm
 
 class ImageSourceIterAsync(SourceIter):
     """
